diff --git a/.circleci/config.yml b/.circleci/config.yml
index 7a70f273..88ff45ec 100644
--- a/.circleci/config.yml
+++ b/.circleci/config.yml
@@ -3,7 +3,7 @@ version: 2
jobs:
osx-python3.6:
macos:
- xcode: 9.4.1
+ xcode: 12.5.1
environment:
PYTHON: python3
steps:
diff --git a/.github/workflows/update-dependencies.yml b/.github/workflows/update-dependencies.yml
index d1370556..1ee0ae71 100644
--- a/.github/workflows/update-dependencies.yml
+++ b/.github/workflows/update-dependencies.yml
@@ -17,6 +17,8 @@ jobs:
run: nox --force-color -s update_constraints
- name: "Run update: python configs"
run: nox --force-color -s update_pins
+ - name: "Run update: docs user projects"
+ run: nox --force-color -s update_proj -- --auth=${{ secrets.GITHUB_TOKEN }}
# we use this step to grab a Github App auth token, so that PRs generated by this workflow
# run the GHA tests.
diff --git a/.pre-commit-config.yaml b/.pre-commit-config.yaml
index 40ceac84..559c771b 100644
--- a/.pre-commit-config.yaml
+++ b/.pre-commit-config.yaml
@@ -14,7 +14,7 @@ repos:
- id: trailing-whitespace
- repo: https://github.com/asottile/pyupgrade
- rev: v2.19.4
+ rev: v2.23.3
hooks:
- id: pyupgrade
name: PyUpgrade 3.6+
@@ -26,12 +26,12 @@ repos:
args: ["--py37-plus"]
- repo: https://github.com/PyCQA/isort
- rev: 5.9.1
+ rev: 5.9.3
hooks:
- id: isort
- repo: https://github.com/psf/black
- rev: 21.6b0
+ rev: 21.7b0
hooks:
- id: black
@@ -42,7 +42,7 @@ repos:
stages: [manual]
- repo: https://github.com/pre-commit/mirrors-mypy
- rev: v0.902
+ rev: v0.910
hooks:
- id: mypy
exclude: ^(bin|cibuildwheel/resources|docs)/.*py$
@@ -54,10 +54,10 @@ repos:
- types-toml
- id: mypy
name: mypy 3.7+ on bin/
- files: ^(bin|docs)/.*py$
+ files: ^((bin|docs)/.*py|noxfile.py)$
args: ["--python-version=3.7", "--scripts-are-modules"]
additional_dependencies:
- - packaging
+ - packaging>=21.0
- rich
- types-jinja2
- types-pyyaml
@@ -77,6 +77,12 @@ repos:
- id: disallow-caps
name: Disallow improper capitalization
language: pygrep
- entry: PyBind|Numpy|Cmake|Github
+ entry: PyBind|Numpy|Cmake|Github|PyTest
types:
- markdown
+
+- repo: https://github.com/codespell-project/codespell
+ rev: v2.1.0
+ hooks:
+ - id: codespell
+ args: ["-L", "sur"]
diff --git a/README.md b/README.md
index 462d41ba..3b2f84e9 100644
--- a/README.md
+++ b/README.md
@@ -28,10 +28,9 @@ What does it do?
| CPython 3.7 | ✅ | N/A | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
| CPython 3.8 | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
| CPython 3.9 | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
-| CPython 3.10¹ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
+| CPython 3.10 | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
| PyPy 3.7 v7.3 | ✅ | N/A | ✅ | N/A | ✅ | ✅ | ✅ | N/A | N/A |
-¹ Available as a prerelease under a [flag](https://cibuildwheel.readthedocs.io/en/stable/options/#prerelease-pythons)
- Builds manylinux, macOS 10.9+, and Windows wheels for CPython and PyPy
- Works on GitHub Actions, Azure Pipelines, Travis CI, AppVeyor, CircleCI, and GitLab CI
@@ -85,7 +84,7 @@ jobs:
- uses: actions/setup-python@v2
- name: Install cibuildwheel
- run: python -m pip install cibuildwheel==2.0.0a3
+ run: python -m pip install cibuildwheel==2.1.1
- name: Build wheels
run: python -m cibuildwheel --output-dir wheelhouse
@@ -107,14 +106,15 @@ Options
|---|--------|-------------|
| **Build selection** | [`CIBW_PLATFORM`](https://cibuildwheel.readthedocs.io/en/stable/options/#platform) | Override the auto-detected target platform |
| | [`CIBW_BUILD`](https://cibuildwheel.readthedocs.io/en/stable/options/#build-skip)
[`CIBW_SKIP`](https://cibuildwheel.readthedocs.io/en/stable/options/#build-skip) | Choose the Python versions to build |
-| | [`CIBW_ARCHS`](https://cibuildwheel.readthedocs.io/en/stable/options/#archs) | Change the architectures built on your machine by default |
+| | [`CIBW_ARCHS`](https://cibuildwheel.readthedocs.io/en/stable/options/#archs) | Change the architectures built on your machine by default. |
| | [`CIBW_PROJECT_REQUIRES_PYTHON`](https://cibuildwheel.readthedocs.io/en/stable/options/#requires-python) | Manually set the Python compatibility of your project |
-| | [`CIBW_PRERELEASE_PYTHONS`](https://cibuildwheel.readthedocs.io/en/stable/options/#prerelease-pythons) | Enable building with pre-release versions of Python |
-| **Build customization** | [`CIBW_ENVIRONMENT`](https://cibuildwheel.readthedocs.io/en/stable/options/#environment) | Set environment variables needed during the build |
+| | [`CIBW_PRERELEASE_PYTHONS`](https://cibuildwheel.readthedocs.io/en/stable/options/#prerelease-pythons) | Enable building with pre-release versions of Python if available |
+| **Build customization** | [`CIBW_BUILD_FRONTEND`](https://cibuildwheel.readthedocs.io/en/stable/options/#build-frontend) | Set the tool to use to build, either "pip" (default for now) or "build" |
+| | [`CIBW_ENVIRONMENT`](https://cibuildwheel.readthedocs.io/en/stable/options/#environment) | Set environment variables needed during the build |
| | [`CIBW_BEFORE_ALL`](https://cibuildwheel.readthedocs.io/en/stable/options/#before-all) | Execute a shell command on the build system before any wheels are built. |
| | [`CIBW_BEFORE_BUILD`](https://cibuildwheel.readthedocs.io/en/stable/options/#before-build) | Execute a shell command preparing each wheel's build |
| | [`CIBW_REPAIR_WHEEL_COMMAND`](https://cibuildwheel.readthedocs.io/en/stable/options/#repair-wheel-command) | Execute a shell command to repair each (non-pure Python) built wheel |
-| | [`CIBW_MANYLINUX_X86_64_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_I686_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_PYPY_X86_64_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_AARCH64_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_PPC64LE_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_S390X_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_PYPY_AARCH64_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image)
[`CIBW_MANYLINUX_PYPY_I686_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image) | Specify alternative manylinux docker images |
+| | [`CIBW_MANYLINUX_*_IMAGE`](https://cibuildwheel.readthedocs.io/en/stable/options/#manylinux-image) | Specify alternative manylinux Docker images |
| | [`CIBW_DEPENDENCY_VERSIONS`](https://cibuildwheel.readthedocs.io/en/stable/options/#dependency-versions) | Specify how cibuildwheel controls the versions of the tools it uses |
| **Testing** | [`CIBW_TEST_COMMAND`](https://cibuildwheel.readthedocs.io/en/stable/options/#test-command) | Execute a shell command to test each built wheel |
| | [`CIBW_BEFORE_TEST`](https://cibuildwheel.readthedocs.io/en/stable/options/#before-test) | Execute a shell command before testing each wheel |
@@ -144,6 +144,7 @@ Here are some repos that use cibuildwheel.
| [psutil][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Cross-platform lib for process and system monitoring in Python |
| [scikit-image][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Image processing library. Uses cibuildwheel to build and test a project that uses Cython with platform-native code. |
| [twisted-iocpsupport][] | ![github icon][] | ![windows icon][] | A submodule of Twisted that hooks into native C APIs using Cython. |
+| [cmake][] | ![github icon][] ![travisci icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Multitagged binary builds for all supported platforms, using cibw 2 config configuration. |
| [websockets][] | ![travisci icon][] | ![apple icon][] ![linux icon][] | Library for building WebSocket servers and clients. Mostly written in Python, with a small C 'speedups' extension module. |
| [pyzmq][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Python bindings for zeromq, the networking library. Uses Cython and CFFI. |
| [aiortc][] | ![github icon][] | ![apple icon][] ![linux icon][] | WebRTC and ORTC implementation for Python using asyncio. |
@@ -163,36 +164,37 @@ Here are some repos that use cibuildwheel.
| [Parselmouth][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | A Python interface to the Praat software package, using pybind11, C++17 and CMake, with the core Praat static library built only once and shared between wheels. |
| [python-rapidjson][] | ![travisci icon][] ![gitlab icon][] ![appveyor icon][] | ![windows icon][] ![linux icon][] | Python wrapper around rapidjson |
| [Rtree][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Rtree: spatial index for Python GIS ¶ |
-| [python-snappy][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Python bindings for the snappy google library |
| [markupsafe][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Safely add untrusted strings to HTML/XML markup. |
| [H3-py][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Python bindings for H3, a hierarchical hexagonal geospatial indexing system |
+| [python-snappy][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Python bindings for the snappy google library |
| [pybind11 cmake_example][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Example pybind11 module built with a CMake-based build system |
| [KDEpy][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Kernel Density Estimation in Python |
| [cyvcf2][] | ![github icon][] | ![apple icon][] ![linux icon][] | cython + htslib == fast VCF and BCF processing |
| [pybind11 python_example][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Example pybind11 module built with a Python-based build system |
-| [sourmash][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Quickly search, compare, and analyze genomic and metagenomic data sets. |
| [dd-trace-py][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Uses custom alternate arch emulation on GitHub |
-| [iminuit][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Jupyter-friendly Python interface for C++ MINUIT2 |
-| [time-machine][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Time mocking library using only the CPython C API. |
-| [CTranslate2][] | ![github icon][] | ![apple icon][] ![linux icon][] | Includes libraries from the [Intel oneAPI toolkit](https://software.intel.com/content/www/us/en/develop/tools/oneapi/base-toolkit.html). The Linux wheels also include CUDA libraries for GPU execution. |
+| [sourmash][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Quickly search, compare, and analyze genomic and metagenomic data sets. |
| [matrixprofile][] | ![travisci icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | A Python 3 library making time series data mining tasks, utilizing matrix profile algorithms, accessible to everyone. |
+| [time-machine][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Time mocking library using only the CPython C API. |
+| [iminuit][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Jupyter-friendly Python interface for C++ MINUIT2 |
+| [CTranslate2][] | ![github icon][] | ![apple icon][] ![linux icon][] | Includes libraries from the [Intel oneAPI toolkit](https://software.intel.com/content/www/us/en/develop/tools/oneapi/base-toolkit.html). The Linux wheels also include CUDA libraries for GPU execution. |
| [jq.py][] | ![travisci icon][] | ![apple icon][] ![linux icon][] | Python bindings for jq |
| [Tokenizer][] | ![github icon][] ![travisci icon][] | ![apple icon][] ![linux icon][] | Fast and customizable text tokenization library with BPE and SentencePiece support |
| [PyGLM][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Fast OpenGL Mathematics (GLM) for Python |
| [bx-python][] | ![travisci icon][] | ![apple icon][] ![linux icon][] | A library that includes Cython extensions. |
| [iDynTree][] | ![github icon][] | ![linux icon][] | Uses manylinux_2_24 |
| [boost-histogram][] | ![github icon][] ![travisci icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Supports full range of wheels, including PyPy and alternate archs. |
-| [TgCrypto][] | ![travisci icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Includes a Windows Travis build. |
| [pybase64][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Fast Base64 encoding/decoding in Python |
+| [TgCrypto][] | ![travisci icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Includes a Windows Travis build. |
| [etebase-py][] | ![travisci icon][] | ![linux icon][] | Python bindings to a Rust library using `setuptools-rust`, and `sccache` for improved speed. |
+| [fathon][] | ![travisci icon][] | ![apple icon][] ![linux icon][] | python package for DFA (Detrended Fluctuation Analysis) and related algorithms |
| [pyjet][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | The interface between FastJet and NumPy |
| [numpythia][] | ![github icon][] | ![apple icon][] ![linux icon][] | The interface between PYTHIA and NumPy |
-| [fathon][] | ![travisci icon][] | ![apple icon][] ![linux icon][] | python package for DFA (Detrended Fluctuation Analysis) and related algorithms |
-| [GSD][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Cython and NumPy project with 64-bit wheels. |
| [polaroid][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Full range of wheels for setuptools rust, with auto release and PyPI deploy. |
+| [ninja][] | ![github icon][] ![travisci icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Multitagged binary builds for all supported platforms, using cibw 2 config configuration. |
+| [Imagecodecs (fork)][] | ![azurepipelines icon][] | ![apple icon][] ![linux icon][] | Over 20 external dependencies in compiled libraries, custom docker image, `libomp`, `openblas` and `install_name_tool` for macOS. |
+| [GSD][] | ![github icon][] | ![apple icon][] ![linux icon][] ![windows icon][] | Cython and NumPy project with 64-bit wheels. |
| [pybind11 scikit_build_example][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | An example combining scikit-build and pybind11 |
| [pyinstrument_cext][] | ![travisci icon][] ![appveyor icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | A simple C extension, without external dependencies |
-| [Imagecodecs (fork)][] | ![azurepipelines icon][] | ![apple icon][] ![linux icon][] | Over 20 external dependencies in compiled libraries, custom docker image, `libomp`, `openblas` and `install_name_tool` for macOS. |
| [xmlstarlet][] | ![github icon][] | ![windows icon][] ![apple icon][] ![linux icon][] | Python 3.6+ CFFI bindings with true MSVC build. |
| [CorrectionLib][] | ![github icon][] | ![apple icon][] ![linux icon][] | Structured JSON powered correction library for HEP, designed for the CMS experiment at CERN. |
| [SiPM][] | ![github icon][] | ![apple icon][] ![linux icon][] | High performance library for SiPM detectors simulation using C++17, OpenMP and AVX2 intrinsics. |
@@ -203,6 +205,7 @@ Here are some repos that use cibuildwheel.
[psutil]: https://github.com/giampaolo/psutil
[scikit-image]: https://github.com/scikit-image/scikit-image
[twisted-iocpsupport]: https://github.com/twisted/twisted-iocpsupport
+[cmake]: https://github.com/scikit-build/cmake-python-distributions
[websockets]: https://github.com/aaugustin/websockets
[pyzmq]: https://github.com/zeromq/pyzmq
[aiortc]: https://github.com/aiortc/aiortc
@@ -222,36 +225,37 @@ Here are some repos that use cibuildwheel.
[Parselmouth]: https://github.com/YannickJadoul/Parselmouth
[python-rapidjson]: https://github.com/python-rapidjson/python-rapidjson
[Rtree]: https://github.com/Toblerity/rtree
-[python-snappy]: https://github.com/andrix/python-snappy
[markupsafe]: https://github.com/pallets/markupsafe
[H3-py]: https://github.com/uber/h3-py
+[python-snappy]: https://github.com/andrix/python-snappy
[pybind11 cmake_example]: https://github.com/pybind/cmake_example
[KDEpy]: https://github.com/tommyod/KDEpy
[cyvcf2]: https://github.com/brentp/cyvcf2
[pybind11 python_example]: https://github.com/pybind/python_example
-[sourmash]: https://github.com/dib-lab/sourmash
[dd-trace-py]: https://github.com/DataDog/dd-trace-py
-[iminuit]: https://github.com/scikit-hep/iminuit
-[time-machine]: https://github.com/adamchainz/time-machine
-[CTranslate2]: https://github.com/OpenNMT/CTranslate2
+[sourmash]: https://github.com/dib-lab/sourmash
[matrixprofile]: https://github.com/matrix-profile-foundation/matrixprofile
+[time-machine]: https://github.com/adamchainz/time-machine
+[iminuit]: https://github.com/scikit-hep/iminuit
+[CTranslate2]: https://github.com/OpenNMT/CTranslate2
[jq.py]: https://github.com/mwilliamson/jq.py
[Tokenizer]: https://github.com/OpenNMT/Tokenizer
[PyGLM]: https://github.com/Zuzu-Typ/PyGLM
[bx-python]: https://github.com/bxlab/bx-python
[iDynTree]: https://github.com/robotology/idyntree
[boost-histogram]: https://github.com/scikit-hep/boost-histogram
-[TgCrypto]: https://github.com/pyrogram/tgcrypto
[pybase64]: https://github.com/mayeut/pybase64
+[TgCrypto]: https://github.com/pyrogram/tgcrypto
[etebase-py]: https://github.com/etesync/etebase-py
+[fathon]: https://github.com/stfbnc/fathon
[pyjet]: https://github.com/scikit-hep/pyjet
[numpythia]: https://github.com/scikit-hep/numpythia
-[fathon]: https://github.com/stfbnc/fathon
-[GSD]: https://github.com/glotzerlab/gsd
[polaroid]: https://github.com/daggy1234/polaroid
+[ninja]: https://github.com/scikit-build/ninja-python-distributions
+[Imagecodecs (fork)]: https://github.com/czaki/imagecodecs_build
+[GSD]: https://github.com/glotzerlab/gsd
[pybind11 scikit_build_example]: https://github.com/pybind/scikit_build_example
[pyinstrument_cext]: https://github.com/joerick/pyinstrument_cext
-[Imagecodecs (fork)]: https://github.com/czaki/imagecodecs_build
[xmlstarlet]: https://github.com/dimitern/xmlstarlet
[CorrectionLib]: https://github.com/cms-nanoAOD/correctionlib
[SiPM]: https://github.com/EdoPro98/SimSiPM
@@ -266,64 +270,66 @@ Here are some repos that use cibuildwheel.
[apple icon]: docs/data/readme_icons/apple.svg
[linux icon]: docs/data/readme_icons/linux.svg
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -347,21 +353,33 @@ Changelog
-### v2.0.0 (prerelease)
+### v2.1.1
-_This release is currently in prerelease. The below release notes will be condensed into a single entry when we do a final release._
+_7 August 2021_
-_v2.0.0a3 (22 Jun 2021)_
+- ✨ Corresponding with the release of CPython 3.10.0rc1, which is ABI stable, cibuildwheel now builds CPython 3.10 by default - without the CIBW_PRERELEASE_PYTHONS flag.
-- 🌟 You can now configure cibuildwheel options inside your project's `pyproject.toml`! Environment variables still work of course. Check out the [documentation](https://cibuildwheel.readthedocs.io/en/latest/options/#setting-options) for more info.
+Note: v2.1.0 was a bad release, it was yanked from PyPI.
-_v2.0.0a2 (1 Jun 2021)_
+### v2.0.1
-- 🌟 Added the ability to test building wheels on CPython 3.10! Because CPython 3.10 is in beta, these wheels should not be distributed, because they might not be compatible with the final release, but it's available to build for testing purposes. Use the flag [`--prerelease-pythons` or `CIBW_PRERELEASE_PYTHONS`](https://cibuildwheel.readthedocs.io/en/latest/options/#prerelease-pythons) to test. (#675)
+_25 July 2021_
+
+- 📚 Docs improvements (#767)
+- 🛠 Dependency updates, including delocate 0.9.0.
+
+### v2.0.0 🎉
+
+_16 July 2021_
+
+- 🌟 You can now configure cibuildwheel options inside your project's `pyproject.toml`! Environment variables still work of course. Check out the [documentation](https://cibuildwheel.readthedocs.io/en/stable/options/#setting-options) for more info.
+- 🌟 Added support for building wheels with [build](https://github.com/pypa/build), as well as pip. This feature is controlled with the [`CIBW_BUILD_FRONTEND`](https://cibuildwheel.readthedocs.io/en/stable/options/#build-frontend) option.
+- 🌟 Added the ability to test building wheels on CPython 3.10! Because CPython 3.10 is in beta, these wheels should not be distributed, because they might not be compatible with the final release, but it's available to build for testing purposes. Use the flag [`--prerelease-pythons` or `CIBW_PRERELEASE_PYTHONS`](https://cibuildwheel.readthedocs.io/en/stable/options/#prerelease-pythons) to test. (#675) This version of cibuildwheel includes CPython 3.10.0b4.
+- ⚠️ **Removed support for building Python 2.7 and Python 3.5 wheels**, for both CPython and PyPy. If you still need to build on these versions, please use the latest v1.x version. (#596)
- ✨ Added the ability to build CPython 3.8 wheels for Apple Silicon. (#704)
-- 🛠 Update to the latest build dependencies, including auditwheel 4. (#633)
+- 🛠 Update to the latest build dependencies, including Auditwheel 4. (#633)
- 🛠 Use the unified pypa/manylinux images to build PyPy (#671)
-- ⚠️ Removed support for building Python 2.7 and Python 3.5 wheels, for both CPython and PyPy. If you still need to build on these versions, please use the latest v1.x version. (#596)
+- 🐛 Numerous bug fixes & docs improvements
### v1.12.0
diff --git a/action.yml b/action.yml
index 6429ff78..4c910ef3 100644
--- a/action.yml
+++ b/action.yml
@@ -17,12 +17,12 @@ runs:
using: composite
steps:
- # This needs powershell-core because github.action path is a Windows-style
- # path on Windows. Powershell-core understands both types of paths.
+ # Redirecting stderr to stdout to fix interleaving issue in Actions.
- run: >
pipx run
- --spec ${{ github.action_path }}
+ --spec '${{ github.action_path }}'
cibuildwheel
${{ inputs.package-dir }}
--output-dir ${{ inputs.output-dir }}
- shell: pwsh
+ 2>&1
+ shell: bash
diff --git a/bin/update_pythons.py b/bin/update_pythons.py
index 4eacb195..457d63a9 100755
--- a/bin/update_pythons.py
+++ b/bin/update_pythons.py
@@ -6,7 +6,7 @@ import copy
import difflib
import logging
from pathlib import Path
-from typing import Any, Iterable, Union, cast
+from typing import Any, Union
import click
import requests
@@ -86,7 +86,7 @@ class WindowsVersions:
# Specifier.filter selects all non pre-releases that match the spec,
# unless there are only pre-releases, then it selects pre-releases
# instead (like pip)
- unsorted_versions = cast(Iterable[Version], spec.filter(self.version_dict))
+ unsorted_versions = spec.filter(self.version_dict)
versions = sorted(unsorted_versions, reverse=True)
log.debug(f"Windows {self.arch} {spec} has {', '.join(str(v) for v in versions)}")
@@ -201,7 +201,7 @@ class CPythonVersions:
) -> ConfigMacOS | None:
# see note above on Specifier.filter
- unsorted_versions = cast(Iterable[Version], spec.filter(self.versions_dict))
+ unsorted_versions = spec.filter(self.versions_dict)
sorted_versions = sorted(unsorted_versions, reverse=True)
if version <= Version("3.8.9999"):
diff --git a/cibuildwheel/__init__.py b/cibuildwheel/__init__.py
index 6d39a388..58039f50 100644
--- a/cibuildwheel/__init__.py
+++ b/cibuildwheel/__init__.py
@@ -1 +1 @@
-__version__ = "2.0.0a3"
+__version__ = "2.1.1"
diff --git a/cibuildwheel/__main__.py b/cibuildwheel/__main__.py
index 1d3ce40c..a1cb85cd 100644
--- a/cibuildwheel/__main__.py
+++ b/cibuildwheel/__main__.py
@@ -20,6 +20,7 @@ from cibuildwheel.options import ConfigOptions
from cibuildwheel.projectfiles import get_requires_python_str
from cibuildwheel.typing import PLATFORMS, PlatformName, assert_never
from cibuildwheel.util import (
+ BuildFrontend,
BuildOptions,
BuildSelector,
DependencyConstraints,
@@ -184,6 +185,7 @@ def main() -> None:
archs_config_str = args.archs or options("archs", sep=" ")
+ build_frontend_str = options("build-frontend", env_plat=False)
environment_config = options("environment", table={"item": '{k}="{v}"', "sep": " "})
before_all = options("before-all", sep=" && ")
before_build = options("before-build", sep=" && ")
@@ -200,6 +202,16 @@ def main() -> None:
os.environ.get("CIBW_PRERELEASE_PYTHONS", "0")
)
+ build_frontend: BuildFrontend
+ if build_frontend_str == "build":
+ build_frontend = "build"
+ elif build_frontend_str == "pip":
+ build_frontend = "pip"
+ else:
+ msg = f"cibuildwheel: Unrecognised build frontend '{build_frontend}', only 'pip' and 'build' are supported"
+ print(msg, file=sys.stderr)
+ sys.exit(2)
+
package_files = {"setup.py", "setup.cfg", "pyproject.toml"}
if not any(package_dir.joinpath(name).exists() for name in package_files):
@@ -308,6 +320,7 @@ def main() -> None:
environment=environment,
dependency_constraints=dependency_constraints,
manylinux_images=manylinux_images or None,
+ build_frontend=build_frontend,
)
# Python is buffering by default when running on the CI platforms, giving problems interleaving subprocess call output with unflushed calls to 'print'
diff --git a/cibuildwheel/resources/build-platforms.toml b/cibuildwheel/resources/build-platforms.toml
index 5ebaf129..e727667d 100644
--- a/cibuildwheel/resources/build-platforms.toml
+++ b/cibuildwheel/resources/build-platforms.toml
@@ -37,12 +37,12 @@ python_configurations = [
{ identifier = "cp38-macosx_x86_64", version = "3.8", url = "https://www.python.org/ftp/python/3.8.10/python-3.8.10-macosx10.9.pkg" },
{ identifier = "cp38-macosx_arm64", version = "3.8", url = "https://www.python.org/ftp/python/3.8.10/python-3.8.10-macosx10.9.pkg" },
{ identifier = "cp38-macosx_universal2", version = "3.8", url = "https://www.python.org/ftp/python/3.8.10/python-3.8.10-macosx10.9.pkg" },
- { identifier = "cp39-macosx_x86_64", version = "3.9", url = "https://www.python.org/ftp/python/3.9.5/python-3.9.5-macos11.pkg" },
- { identifier = "cp39-macosx_arm64", version = "3.9", url = "https://www.python.org/ftp/python/3.9.5/python-3.9.5-macos11.pkg" },
- { identifier = "cp39-macosx_universal2", version = "3.9", url = "https://www.python.org/ftp/python/3.9.5/python-3.9.5-macos11.pkg" },
- { identifier = "cp310-macosx_x86_64", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0b3-macos11.pkg" },
- { identifier = "cp310-macosx_arm64", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0b3-macos11.pkg" },
- { identifier = "cp310-macosx_universal2", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0b3-macos11.pkg" },
+ { identifier = "cp39-macosx_x86_64", version = "3.9", url = "https://www.python.org/ftp/python/3.9.6/python-3.9.6-macos11.pkg" },
+ { identifier = "cp39-macosx_arm64", version = "3.9", url = "https://www.python.org/ftp/python/3.9.6/python-3.9.6-macos11.pkg" },
+ { identifier = "cp39-macosx_universal2", version = "3.9", url = "https://www.python.org/ftp/python/3.9.6/python-3.9.6-macos11.pkg" },
+ { identifier = "cp310-macosx_x86_64", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0rc1-macos11.pkg" },
+ { identifier = "cp310-macosx_arm64", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0rc1-macos11.pkg" },
+ { identifier = "cp310-macosx_universal2", version = "3.10", url = "https://www.python.org/ftp/python/3.10.0/python-3.10.0rc1-macos11.pkg" },
{ identifier = "pp37-macosx_x86_64", version = "3.7", url = "https://downloads.python.org/pypy/pypy3.7-v7.3.5-osx64.tar.bz2" },
]
@@ -54,9 +54,9 @@ python_configurations = [
{ identifier = "cp37-win_amd64", version = "3.7.9", arch = "64" },
{ identifier = "cp38-win32", version = "3.8.10", arch = "32" },
{ identifier = "cp38-win_amd64", version = "3.8.10", arch = "64" },
- { identifier = "cp39-win32", version = "3.9.5", arch = "32" },
- { identifier = "cp39-win_amd64", version = "3.9.5", arch = "64" },
- { identifier = "cp310-win32", version = "3.10.0-b3", arch = "32" },
- { identifier = "cp310-win_amd64", version = "3.10.0-b3", arch = "64" },
+ { identifier = "cp39-win32", version = "3.9.6", arch = "32" },
+ { identifier = "cp39-win_amd64", version = "3.9.6", arch = "64" },
+ { identifier = "cp310-win32", version = "3.10.0-rc1", arch = "32" },
+ { identifier = "cp310-win_amd64", version = "3.10.0-rc1", arch = "64" },
{ identifier = "pp37-win_amd64", version = "3.7", arch = "64", url = "https://downloads.python.org/pypy/pypy3.7-v7.3.5-win64.zip" },
]
diff --git a/cibuildwheel/resources/constraints-python36.txt b/cibuildwheel/resources/constraints-python36.txt
index 4334fec7..25811f76 100644
--- a/cibuildwheel/resources/constraints-python36.txt
+++ b/cibuildwheel/resources/constraints-python36.txt
@@ -1,38 +1,46 @@
#
-# This file is autogenerated by pip-compile
+# This file is autogenerated by pip-compile with python 3.6
# To update, run:
#
# bin/update_dependencies.py
#
-appdirs==1.4.4
+backports.entry-points-selectable==1.1.0
# via virtualenv
-delocate==0.8.2
+delocate==0.9.0
# via -r cibuildwheel/resources/constraints.in
distlib==0.3.2
# via virtualenv
filelock==3.0.12
# via virtualenv
-importlib-metadata==4.5.0
+importlib-metadata==4.6.4
+ # via
+ # backports.entry-points-selectable
+ # virtualenv
+importlib-resources==5.2.2
# via virtualenv
-importlib-resources==5.1.4
+platformdirs==2.2.0
# via virtualenv
six==1.16.0
- # via virtualenv
+ # via
+ # delocate
+ # virtualenv
typing-extensions==3.10.0.0
- # via importlib-metadata
-virtualenv==20.4.7
+ # via
+ # delocate
+ # importlib-metadata
+virtualenv==20.7.2
# via -r cibuildwheel/resources/constraints.in
-wheel==0.36.2
+wheel==0.37.0
# via
# -r cibuildwheel/resources/constraints.in
# delocate
-zipp==3.4.1
+zipp==3.5.0
# via
# importlib-metadata
# importlib-resources
# The following packages are considered to be unsafe in a requirements file:
-pip==21.1.2
+pip==21.2.4
# via -r cibuildwheel/resources/constraints.in
-setuptools==57.0.0
+setuptools==57.4.0
# via -r cibuildwheel/resources/constraints.in
diff --git a/cibuildwheel/resources/constraints-python37.txt b/cibuildwheel/resources/constraints-python37.txt
index 3fc1587b..5f6347e2 100644
--- a/cibuildwheel/resources/constraints-python37.txt
+++ b/cibuildwheel/resources/constraints-python37.txt
@@ -1,34 +1,42 @@
#
-# This file is autogenerated by pip-compile
+# This file is autogenerated by pip-compile with python 3.7
# To update, run:
#
# bin/update_dependencies.py
#
-appdirs==1.4.4
+backports.entry-points-selectable==1.1.0
# via virtualenv
-delocate==0.8.2
+delocate==0.9.0
# via -r cibuildwheel/resources/constraints.in
distlib==0.3.2
# via virtualenv
filelock==3.0.12
# via virtualenv
-importlib-metadata==4.5.0
+importlib-metadata==4.6.4
+ # via
+ # backports.entry-points-selectable
+ # virtualenv
+platformdirs==2.2.0
# via virtualenv
six==1.16.0
- # via virtualenv
+ # via
+ # delocate
+ # virtualenv
typing-extensions==3.10.0.0
- # via importlib-metadata
-virtualenv==20.4.7
+ # via
+ # delocate
+ # importlib-metadata
+virtualenv==20.7.2
# via -r cibuildwheel/resources/constraints.in
-wheel==0.36.2
+wheel==0.37.0
# via
# -r cibuildwheel/resources/constraints.in
# delocate
-zipp==3.4.1
+zipp==3.5.0
# via importlib-metadata
# The following packages are considered to be unsafe in a requirements file:
-pip==21.1.2
+pip==21.2.4
# via -r cibuildwheel/resources/constraints.in
-setuptools==57.0.0
+setuptools==57.4.0
# via -r cibuildwheel/resources/constraints.in
diff --git a/cibuildwheel/resources/constraints-python38.txt b/cibuildwheel/resources/constraints-python38.txt
index e12207ec..3f8702aa 100644
--- a/cibuildwheel/resources/constraints-python38.txt
+++ b/cibuildwheel/resources/constraints-python38.txt
@@ -1,28 +1,34 @@
#
-# This file is autogenerated by pip-compile
+# This file is autogenerated by pip-compile with python 3.8
# To update, run:
#
# bin/update_dependencies.py
#
-appdirs==1.4.4
+backports.entry-points-selectable==1.1.0
# via virtualenv
-delocate==0.8.2
+delocate==0.9.0
# via -r cibuildwheel/resources/constraints.in
distlib==0.3.2
# via virtualenv
filelock==3.0.12
# via virtualenv
-six==1.16.0
+platformdirs==2.2.0
# via virtualenv
-virtualenv==20.4.7
+six==1.16.0
+ # via
+ # delocate
+ # virtualenv
+typing-extensions==3.10.0.0
+ # via delocate
+virtualenv==20.7.2
# via -r cibuildwheel/resources/constraints.in
-wheel==0.36.2
+wheel==0.37.0
# via
# -r cibuildwheel/resources/constraints.in
# delocate
# The following packages are considered to be unsafe in a requirements file:
-pip==21.1.2
+pip==21.2.4
# via -r cibuildwheel/resources/constraints.in
-setuptools==57.0.0
+setuptools==57.4.0
# via -r cibuildwheel/resources/constraints.in
diff --git a/cibuildwheel/resources/constraints-python39.txt b/cibuildwheel/resources/constraints-python39.txt
index e12207ec..57687a6f 100644
--- a/cibuildwheel/resources/constraints-python39.txt
+++ b/cibuildwheel/resources/constraints-python39.txt
@@ -1,28 +1,34 @@
#
-# This file is autogenerated by pip-compile
+# This file is autogenerated by pip-compile with python 3.9
# To update, run:
#
# bin/update_dependencies.py
#
-appdirs==1.4.4
+backports.entry-points-selectable==1.1.0
# via virtualenv
-delocate==0.8.2
+delocate==0.9.0
# via -r cibuildwheel/resources/constraints.in
distlib==0.3.2
# via virtualenv
filelock==3.0.12
# via virtualenv
-six==1.16.0
+platformdirs==2.2.0
# via virtualenv
-virtualenv==20.4.7
+six==1.16.0
+ # via
+ # delocate
+ # virtualenv
+typing-extensions==3.10.0.0
+ # via delocate
+virtualenv==20.7.2
# via -r cibuildwheel/resources/constraints.in
-wheel==0.36.2
+wheel==0.37.0
# via
# -r cibuildwheel/resources/constraints.in
# delocate
# The following packages are considered to be unsafe in a requirements file:
-pip==21.1.2
+pip==21.2.4
# via -r cibuildwheel/resources/constraints.in
-setuptools==57.0.0
+setuptools==57.4.0
# via -r cibuildwheel/resources/constraints.in
diff --git a/cibuildwheel/resources/constraints.txt b/cibuildwheel/resources/constraints.txt
index e12207ec..57687a6f 100644
--- a/cibuildwheel/resources/constraints.txt
+++ b/cibuildwheel/resources/constraints.txt
@@ -1,28 +1,34 @@
#
-# This file is autogenerated by pip-compile
+# This file is autogenerated by pip-compile with python 3.9
# To update, run:
#
# bin/update_dependencies.py
#
-appdirs==1.4.4
+backports.entry-points-selectable==1.1.0
# via virtualenv
-delocate==0.8.2
+delocate==0.9.0
# via -r cibuildwheel/resources/constraints.in
distlib==0.3.2
# via virtualenv
filelock==3.0.12
# via virtualenv
-six==1.16.0
+platformdirs==2.2.0
# via virtualenv
-virtualenv==20.4.7
+six==1.16.0
+ # via
+ # delocate
+ # virtualenv
+typing-extensions==3.10.0.0
+ # via delocate
+virtualenv==20.7.2
# via -r cibuildwheel/resources/constraints.in
-wheel==0.36.2
+wheel==0.37.0
# via
# -r cibuildwheel/resources/constraints.in
# delocate
# The following packages are considered to be unsafe in a requirements file:
-pip==21.1.2
+pip==21.2.4
# via -r cibuildwheel/resources/constraints.in
-setuptools==57.0.0
+setuptools==57.4.0
# via -r cibuildwheel/resources/constraints.in
diff --git a/cibuildwheel/resources/defaults.toml b/cibuildwheel/resources/defaults.toml
index a9ecff02..5bf179c8 100644
--- a/cibuildwheel/resources/defaults.toml
+++ b/cibuildwheel/resources/defaults.toml
@@ -4,6 +4,7 @@ skip = ""
test-skip = ""
archs = ["auto"]
+build-frontend = "pip"
dependency-versions = "pinned"
environment = {}
build-verbosity = ""
diff --git a/cibuildwheel/resources/pinned_docker_images.cfg b/cibuildwheel/resources/pinned_docker_images.cfg
index 6e9ad226..7f07856d 100644
--- a/cibuildwheel/resources/pinned_docker_images.cfg
+++ b/cibuildwheel/resources/pinned_docker_images.cfg
@@ -1,38 +1,38 @@
[x86_64]
-manylinux1 = quay.io/pypa/manylinux1_x86_64:2021-05-31-f12b4c4
-manylinux2010 = quay.io/pypa/manylinux2010_x86_64:2021-06-07-00faba2
-manylinux2014 = quay.io/pypa/manylinux2014_x86_64:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_x86_64:2021-06-07-00faba2
+manylinux1 = quay.io/pypa/manylinux1_x86_64:2021-08-01-f71d505
+manylinux2010 = quay.io/pypa/manylinux2010_x86_64:2021-08-09-92f447b
+manylinux2014 = quay.io/pypa/manylinux2014_x86_64:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_x86_64:2021-08-09-92f447b
[i686]
-manylinux1 = quay.io/pypa/manylinux1_i686:2021-05-31-f12b4c4
-manylinux2010 = quay.io/pypa/manylinux2010_i686:2021-06-07-00faba2
-manylinux2014 = quay.io/pypa/manylinux2014_i686:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_i686:2021-06-07-00faba2
+manylinux1 = quay.io/pypa/manylinux1_i686:2021-08-01-f71d505
+manylinux2010 = quay.io/pypa/manylinux2010_i686:2021-08-09-92f447b
+manylinux2014 = quay.io/pypa/manylinux2014_i686:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_i686:2021-08-09-92f447b
[pypy_x86_64]
-manylinux2010 = quay.io/pypa/manylinux2010_x86_64:2021-06-07-00faba2
-manylinux2014 = quay.io/pypa/manylinux2014_x86_64:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_x86_64:2021-06-07-00faba2
+manylinux2010 = quay.io/pypa/manylinux2010_x86_64:2021-08-09-92f447b
+manylinux2014 = quay.io/pypa/manylinux2014_x86_64:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_x86_64:2021-08-09-92f447b
[pypy_i686]
-manylinux2010 = quay.io/pypa/manylinux2010_i686:2021-06-07-00faba2
-manylinux2014 = quay.io/pypa/manylinux2014_i686:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_i686:2021-06-07-00faba2
+manylinux2010 = quay.io/pypa/manylinux2010_i686:2021-08-09-92f447b
+manylinux2014 = quay.io/pypa/manylinux2014_i686:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_i686:2021-08-09-92f447b
[aarch64]
-manylinux2014 = quay.io/pypa/manylinux2014_aarch64:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_aarch64:2021-06-07-00faba2
+manylinux2014 = quay.io/pypa/manylinux2014_aarch64:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_aarch64:2021-08-09-92f447b
[ppc64le]
-manylinux2014 = quay.io/pypa/manylinux2014_ppc64le:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_ppc64le:2021-06-07-00faba2
+manylinux2014 = quay.io/pypa/manylinux2014_ppc64le:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_ppc64le:2021-08-09-92f447b
[s390x]
-manylinux2014 = quay.io/pypa/manylinux2014_s390x:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_s390x:2021-06-07-00faba2
+manylinux2014 = quay.io/pypa/manylinux2014_s390x:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_s390x:2021-08-09-92f447b
[pypy_aarch64]
-manylinux2014 = quay.io/pypa/manylinux2014_aarch64:2021-06-07-00faba2
-manylinux_2_24 = quay.io/pypa/manylinux_2_24_aarch64:2021-06-07-00faba2
+manylinux2014 = quay.io/pypa/manylinux2014_aarch64:2021-08-09-92f447b
+manylinux_2_24 = quay.io/pypa/manylinux_2_24_aarch64:2021-08-09-92f447b
diff --git a/cibuildwheel/util.py b/cibuildwheel/util.py
index 5d5c4768..581799cf 100644
--- a/cibuildwheel/util.py
+++ b/cibuildwheel/util.py
@@ -4,6 +4,8 @@ import itertools
import os
import re
import ssl
+import subprocess
+import sys
import textwrap
import time
import urllib.request
@@ -20,12 +22,14 @@ from packaging.version import Version
from .architecture import Architecture
from .environment import ParsedEnvironment
-from .typing import PathOrStr, PlatformName
+from .typing import Literal, PathOrStr, PlatformName
resources_dir = Path(__file__).parent / "resources"
install_certifi_script = resources_dir / "install_certifi.py"
+BuildFrontend = Literal["pip", "build"]
+
def prepare_command(command: str, **kwargs: PathOrStr) -> str:
"""
@@ -63,7 +67,7 @@ class IdentifierSelector:
"""
# a pattern that skips prerelease versions, when include_prereleases is False.
- PRERELEASE_SKIP = "cp310-*"
+ PRERELEASE_SKIP = ""
def __init__(
self,
@@ -140,8 +144,8 @@ class Unbuffered:
self.stream.write(data)
self.stream.flush()
- def writelines(self, datas): # type: ignore
- self.stream.writelines(datas)
+ def writelines(self, data): # type: ignore
+ self.stream.writelines(data)
self.stream.flush()
def __getattr__(self, attr): # type: ignore
@@ -218,6 +222,7 @@ class BuildOptions(NamedTuple):
test_requires: List[str]
test_extras: str
build_verbosity: int
+ build_frontend: BuildFrontend
class NonPlatformWheelError(Exception):
@@ -300,3 +305,18 @@ def print_new_wheels(msg: str, output_dir: Path) -> Iterator[None]:
s = time.time() - start_time
m = s / 60
print(msg.format(n=n, s=s, m=m), *sorted(f" {f.name}" for f in new_contents), sep="\n")
+
+
+def get_pip_version(env: Dict[str, str]) -> str:
+ # we use shell=True here for windows, even though we don't need a shell due to a bug
+ # https://bugs.python.org/issue8557
+ shell = sys.platform.startswith("win")
+ versions_output_text = subprocess.check_output(
+ ["python", "-m", "pip", "freeze", "--all"], universal_newlines=True, shell=shell, env=env
+ )
+ (pip_version,) = (
+ version[5:]
+ for version in versions_output_text.strip().splitlines()
+ if version.startswith("pip==")
+ )
+ return pip_version
diff --git a/cibuildwheel/windows.py b/cibuildwheel/windows.py
index 9ce8e309..33e3b236 100644
--- a/cibuildwheel/windows.py
+++ b/cibuildwheel/windows.py
@@ -10,20 +10,24 @@ from zipfile import ZipFile
from .architecture import Architecture
from .environment import ParsedEnvironment
from .logger import log
-from .typing import PathOrStr
+from .typing import PathOrStr, assert_never
from .util import (
+ BuildFrontend,
BuildOptions,
BuildSelector,
NonPlatformWheelError,
download,
get_build_verbosity_extra_flags,
+ get_pip_version,
prepare_command,
read_python_configs,
)
+CIBW_INSTALL_PATH = Path("C:\\cibw")
+
def call(
- args: Sequence[PathOrStr], env: Optional[Dict[str, str]] = None, cwd: Optional[str] = None
+ args: Sequence[PathOrStr], env: Optional[Dict[str, str]] = None, cwd: Optional[PathOrStr] = None
) -> None:
print("+ " + " ".join(str(a) for a in args))
# we use shell=True here, even though we don't need a shell due to a bug
@@ -31,7 +35,9 @@ def call(
subprocess.run([str(a) for a in args], env=env, cwd=cwd, shell=True, check=True)
-def shell(command: str, env: Optional[Dict[str, str]] = None, cwd: Optional[str] = None) -> None:
+def shell(
+ command: str, env: Optional[Dict[str, str]] = None, cwd: Optional[PathOrStr] = None
+) -> None:
print(f"+ {command}")
subprocess.run(command, env=env, cwd=cwd, shell=True, check=True)
@@ -47,7 +53,7 @@ def get_nuget_args(version: str, arch: str) -> List[str]:
"-FallbackSource",
"https://api.nuget.org/v3/index.json",
"-OutputDirectory",
- "C:\\cibw\\python",
+ str(CIBW_INSTALL_PATH / "python"),
]
@@ -100,9 +106,9 @@ def install_pypy(version: str, arch: str, url: str) -> Path:
zip_filename = url.rsplit("/", 1)[-1]
extension = ".zip"
assert zip_filename.endswith(extension)
- installation_path = Path("C:\\cibw") / zip_filename[: -len(extension)]
+ installation_path = CIBW_INSTALL_PATH / zip_filename[: -len(extension)]
if not installation_path.exists():
- pypy_zip = Path("C:\\cibw") / zip_filename
+ pypy_zip = CIBW_INSTALL_PATH / zip_filename
download(url, pypy_zip)
# Extract to the parent directory because the zip file still contains a directory
extract_zip(pypy_zip, installation_path.parent)
@@ -114,8 +120,10 @@ def setup_python(
python_configuration: PythonConfiguration,
dependency_constraint_flags: Sequence[PathOrStr],
environment: ParsedEnvironment,
+ build_frontend: BuildFrontend,
) -> Dict[str, str]:
- nuget = Path("C:\\cibw\\nuget.exe")
+
+ nuget = CIBW_INSTALL_PATH / "nuget.exe"
if not nuget.exists():
log.step("Downloading nuget...")
download("https://dist.nuget.org/win-x86-commandline/latest/nuget.exe", nuget)
@@ -180,7 +188,7 @@ def setup_python(
requires_reinstall = not (installation_path / "Scripts" / "pip.exe").exists()
if requires_reinstall:
# maybe pip isn't installed at all. ensurepip resolves that.
- call(["python", "-m", "ensurepip"], env=env, cwd="C:\\cibw")
+ call(["python", "-m", "ensurepip"], env=env, cwd=CIBW_INSTALL_PATH)
# upgrade pip to the version matching our constraints
# if necessary, reinstall it to ensure that it's available on PATH as 'pip.exe'
@@ -195,7 +203,7 @@ def setup_python(
*dependency_constraint_flags,
],
env=env,
- cwd="C:\\cibw",
+ cwd=CIBW_INSTALL_PATH,
)
assert (installation_path / "Scripts" / "pip.exe").exists()
@@ -214,10 +222,26 @@ def setup_python(
sys.exit(1)
call(["pip", "--version"], env=env)
- call(
- ["pip", "install", "--upgrade", "setuptools", "wheel", *dependency_constraint_flags],
- env=env,
- )
+
+ if build_frontend == "pip":
+ call(
+ [
+ "pip",
+ "install",
+ "--upgrade",
+ "setuptools",
+ "wheel",
+ *dependency_constraint_flags,
+ ],
+ env=env,
+ )
+ elif build_frontend == "build":
+ call(
+ ["pip", "install", "--upgrade", "build[virtualenv]", *dependency_constraint_flags],
+ env=env,
+ )
+ else:
+ assert_never(build_frontend)
return env
@@ -251,7 +275,12 @@ def build(options: BuildOptions) -> None:
]
# install Python
- env = setup_python(config, dependency_constraint_flags, options.environment)
+ env = setup_python(
+ config,
+ dependency_constraint_flags,
+ options.environment,
+ options.build_frontend,
+ )
# run the before_build command
if options.before_build:
@@ -265,20 +294,60 @@ def build(options: BuildOptions) -> None:
if built_wheel_dir.exists():
shutil.rmtree(built_wheel_dir)
built_wheel_dir.mkdir(parents=True)
- # Path.resolve() is needed. Without it pip wheel may try to fetch package from pypi.org
- # see https://github.com/pypa/cibuildwheel/pull/369
- call(
- [
- "pip",
- "wheel",
- options.package_dir.resolve(),
- "-w",
- built_wheel_dir,
- "--no-deps",
- *get_build_verbosity_extra_flags(options.build_verbosity),
- ],
- env=env,
- )
+
+ verbosity_flags = get_build_verbosity_extra_flags(options.build_verbosity)
+
+ if options.build_frontend == "pip":
+ # Path.resolve() is needed. Without it pip wheel may try to fetch package from pypi.org
+ # see https://github.com/pypa/cibuildwheel/pull/369
+ call(
+ [
+ "python",
+ "-m",
+ "pip",
+ "wheel",
+ options.package_dir.resolve(),
+ f"--wheel-dir={built_wheel_dir}",
+ "--no-deps",
+ *get_build_verbosity_extra_flags(options.build_verbosity),
+ ],
+ env=env,
+ )
+ elif options.build_frontend == "build":
+ config_setting = " ".join(verbosity_flags)
+ build_env = env.copy()
+ if options.dependency_constraints:
+ constraints_path = options.dependency_constraints.get_for_python_version(
+ config.version
+ )
+ # Bug in pip <= 21.1.3 - we can't have a space in the
+ # constraints file, and pip doesn't support drive letters
+ # in uhi. After probably pip 21.2, we can use uri. For
+ # now, use a temporary file.
+ if " " in str(constraints_path):
+ tmp_file = tempfile.NamedTemporaryFile(
+ "w", suffix="constraints.txt", delete=False, dir=CIBW_INSTALL_PATH
+ )
+ with tmp_file as new_constraints_file, open(constraints_path) as f:
+ new_constraints_file.write(f.read())
+ constraints_path = Path(new_constraints_file.name)
+
+ build_env["PIP_CONSTRAINT"] = str(constraints_path)
+ build_env["VIRTUALENV_PIP"] = get_pip_version(env)
+ call(
+ [
+ "python",
+ "-m",
+ "build",
+ options.package_dir,
+ "--wheel",
+ f"--outdir={built_wheel_dir}",
+ f"--config-setting={config_setting}",
+ ],
+ env=build_env,
+ )
+ else:
+ assert_never(options.build_frontend)
built_wheel = next(built_wheel_dir.glob("*.whl"))
diff --git a/docs/contributing.md b/docs/contributing.md
index 3cd7e729..526c46ee 100644
--- a/docs/contributing.md
+++ b/docs/contributing.md
@@ -20,7 +20,7 @@ Design Goals
Other notes:
-- The platforms are very similar, until they're not. I'd rather have straight-forward code than totally DRY code, so let's keep airy platfrom abstractions to a minimum.
+- The platforms are very similar, until they're not. I'd rather have straight-forward code than totally DRY code, so let's keep airy platform abstractions to a minimum.
- I might want to break the options into a shared config file one day, so that config is more easily shared. That has motivated some of the design decisions.
### cibuildwheel's relationship with build errors
diff --git a/docs/data/projects.yml b/docs/data/projects.yml
index dc390ce8..e21af4b5 100644
--- a/docs/data/projects.yml
+++ b/docs/data/projects.yml
@@ -363,3 +363,16 @@
gh: LAMDA-NJU/Deep-Forest
ci: [github]
os: [apple, linux, windows]
+
+- name: cmake
+ gh: scikit-build/cmake-python-distributions
+ stars: Kitware/CMake
+ ci: [github, travisci]
+ os: [apple, linux, windows]
+ notes: Multitagged binary builds for all supported platforms, using cibw 2 config configuration.
+
+- name: ninja
+ gh: scikit-build/ninja-python-distributions
+ ci: [github, travisci]
+ os: [apple, linux, windows]
+ notes: Multitagged binary builds for all supported platforms, using cibw 2 config configuration.
diff --git a/docs/extra.css b/docs/extra.css
index 6f6c8284..e3599627 100644
--- a/docs/extra.css
+++ b/docs/extra.css
@@ -157,7 +157,7 @@ h1, h2, h3, h4, h5, h6 {
}
.tabs-header button:focus-visible {
- /* preserve an outline for accesibility purposes */
+ /* preserve an outline for accessibility purposes */
outline: 1px solid currentColor;
outline-offset: -1px;
}
diff --git a/docs/faq.md b/docs/faq.md
index 4d0d2806..9b70577b 100644
--- a/docs/faq.md
+++ b/docs/faq.md
@@ -127,12 +127,12 @@ There are two suggested methods for keeping cibuildwheel up to date that instead
If you use GitHub Actions for builds, you can use cibuildwheel as an action:
```yaml
-uses: pypa/cibuildwheel@v2.0.0a3
+uses: pypa/cibuildwheel@v2.1.1
```
This is a composite step that just runs cibuildwheel using pipx. You can set command-line options as `with:` parameters, and use `env:` as normal.
-Then, your `dependabot.yml` file could look like this:
+Then, your `.github/dependabot.yml` file could look like this:
```yaml
version: 2
@@ -153,10 +153,10 @@ The second option, and the only one that supports other CI systems, is using a `
```bash
# requirements-cibw.txt
-cibuildwheel==2.0.0a3
+cibuildwheel==2.1.1
```
-Then your install step would have `python -m pip install -r requirements-cibw.txt` in it. Your `dependabot.yml` file could look like this:
+Then your install step would have `python -m pip install -r requirements-cibw.txt` in it. Your `.github/dependabot.yml` file could look like this:
```yaml
version: 2
diff --git a/docs/options.md b/docs/options.md
index aac21f94..53637f1d 100644
--- a/docs/options.md
+++ b/docs/options.md
@@ -155,7 +155,7 @@ When setting the options, you can use shell-style globbing syntax, as per [fnmat
|--------------|---------------------------------------------------------------------|-------------------------------|-----------------------------------------------|----------------------------------------------------------------------------|
| Python 3.6 | cp36-macosx_x86_64 | cp36-win_amd64
cp36-win32 | cp36-manylinux_x86_64
cp36-manylinux_i686 | cp36-manylinux_aarch64
cp36-manylinux_ppc64le
cp36-manylinux_s390x |
| Python 3.7 | cp37-macosx_x86_64 | cp37-win_amd64
cp37-win32 | cp37-manylinux_x86_64
cp37-manylinux_i686 | cp37-manylinux_aarch64
cp37-manylinux_ppc64le
cp37-manylinux_s390x |
-| Python 3.8 | cp38-macosx_x86_64 | cp38-win_amd64
cp38-win32 | cp38-manylinux_x86_64
cp38-manylinux_i686 | cp38-manylinux_aarch64
cp38-manylinux_ppc64le
cp38-manylinux_s390x |
+| Python 3.8 | cp38-macosx_x86_64
cp38-macosx_universal2
cp38-macosx_arm64 | cp38-win_amd64
cp38-win32 | cp38-manylinux_x86_64
cp38-manylinux_i686 | cp38-manylinux_aarch64
cp38-manylinux_ppc64le
cp38-manylinux_s390x |
| Python 3.9 | cp39-macosx_x86_64
cp39-macosx_universal2
cp39-macosx_arm64 | cp39-win_amd64
cp39-win32 | cp39-manylinux_x86_64
cp39-manylinux_i686 | cp39-manylinux_aarch64
cp39-manylinux_ppc64le
cp39-manylinux_s390x |
| PyPy3.7 v7.3 | pp37-macosx_x86_64 | pp37-win_amd64 | pp37-manylinux_x86_64 | |
@@ -240,7 +240,7 @@ See the [cibuildwheel 1 documentation](https://cibuildwheel.readthedocs.io/en/1.
skip = "pp*"
```
- It is generally recommened to set `CIBW_BUILD` as an environment variable, though `skip`
+ It is generally recommended to set `CIBW_BUILD` as an environment variable, though `skip`
tends to be useful in a config file; you can statically declare that you don't
support pypy, for example.
@@ -330,14 +330,14 @@ This option can also be set using the [command-line option](#command-line) `--ar
# Note that the `arm64` wheel and the `arm64` part of the `universal2`
# wheel cannot be tested in this configuration.
[tool.cibuildwheel.macos]
- archs: ["x86_64", "universal2", "arm64"]
+ archs = ["x86_64", "universal2", "arm64"]
# On an Linux Intel runner with qemu installed, build Intel and ARM wheels
[tool.cibuildwheel.linux]
- archs: ["auto", "aarch64"]
+ archs = ["auto", "aarch64"]
```
- It is generally recommmended to use the environment variable or
+ It is generally recommended to use the environment variable or
command-line option for Linux, as selecting archs often depends
on your specific runner having qemu installed.
@@ -406,7 +406,7 @@ This option is not available in `pyproject.toml` under
```
### `CIBW_PRERELEASE_PYTHONS` {: #prerelease-pythons}
-> Enable building with pre-release versions of Python
+> Enable building with pre-release versions of Python if available
During the beta period, when new versions of Python are being tested,
cibuildwheel will often gain early support for beta releases. If you would
@@ -435,6 +435,45 @@ This option can also be set using the [command-line option](#command-line) `--pr
## Build customization
+### `CIBW_BUILD_FRONTEND` {: #build-frontend}
+> Set the tool to use to build, either "pip" (default for now) or "build"
+
+Choose which build backend to use. Can either be "pip", which will run
+`python -m pip wheel`, or "build", which will run `python -m build --wheel`.
+
+!!! tip
+ Until v2.0.0, [pip] was the only way to build wheels, and is still the
+ default. However, we expect that at some point in the future, cibuildwheel
+ will change the default to [build], in line with the PyPA's recommendation.
+ If you want to try `build` before this, you can use this option.
+
+[pip]: https://pip.pypa.io/en/stable/cli/pip_wheel/
+[build]: https://github.com/pypa/build/
+
+#### Examples
+
+!!! tab examples "Environment variables"
+
+ ```yaml
+ # Switch to using build
+ CIBW_BUILD_FRONTEND: "build"
+
+ # Ensure pip is used even if the default changes in the future
+ CIBW_BUILD_FRONTEND: "pip"
+ ```
+
+!!! tab examples "pyproject.toml"
+
+ ```toml
+ [tool.cibuildwheel]
+ # Switch to using build
+ build-frontend = "build"
+
+ # Ensure pip is used even if the default changes in the future
+ build-frontend = "pip"
+ ```
+
+
### `CIBW_ENVIRONMENT` {: #environment}
> Set environment variables needed during the build
@@ -455,19 +494,23 @@ Platform-specific environment variables are also available:
```yaml
# Set some compiler flags
- CIBW_ENVIRONMENT: "CFLAGS='-g -Wall' CXXFLAGS='-Wall'"
+ CIBW_ENVIRONMENT: CFLAGS='-g -Wall' CXXFLAGS='-Wall'
# Append a directory to the PATH variable (this is expanded in the build environment)
- CIBW_ENVIRONMENT: "PATH=$PATH:/usr/local/bin"
+ CIBW_ENVIRONMENT: PATH=$PATH:/usr/local/bin
+
+ # Prepend a directory containing spaces on Windows.
+ CIBW_ENVIRONMENT_WINDOWS: >
+ PATH="C:\\Program Files\\PostgreSQL\\13\\bin;$PATH"
# Set BUILD_TIME to the output of the `date` command
- CIBW_ENVIRONMENT: "BUILD_TIME=$(date)"
+ CIBW_ENVIRONMENT: BUILD_TIME="$(date)"
# Supply options to `pip` to affect how it downloads dependencies
- CIBW_ENVIRONMENT: "PIP_EXTRA_INDEX_URL=https://pypi.myorg.com/simple"
+ CIBW_ENVIRONMENT: PIP_EXTRA_INDEX_URL=https://pypi.myorg.com/simple
# Set two flags on linux only
- CIBW_ENVIRONMENT_LINUX: "BUILD_TIME=$(date) SAMPLE_TEXT=\"sample text\""
+ CIBW_ENVIRONMENT_LINUX: BUILD_TIME="$(date)" SAMPLE_TEXT="sample text"
```
Separate multiple values with a space.
@@ -485,6 +528,10 @@ Platform-specific environment variables are also available:
# Append a directory to the PATH variable (this is expanded in the build environment)
environment = { PATH="$PATH:/usr/local/bin" }
+ # Prepend a directory containing spaces on Windows.
+ [tool.cibuildwheel.windows]
+ environment = { PATH='C:\\Program Files\\PostgreSQL\\13\\bin;$PATH' }
+
# Set BUILD_TIME to the output of the `date` command
environment = { BUILD_TIME="$(date)" }
@@ -529,7 +576,7 @@ Platform-specific environment variables also available:
CIBW_BEFORE_ALL: make -C third_party_lib
# Install system library
- CIBW_BEFORE_ALL_LINUX: yum install -y libffi-dev
+ CIBW_BEFORE_ALL_LINUX: yum install -y libffi-devel
# Chain multiple commands using && and > in a YAML file, like:
CIBW_BEFORE_ALL: >
@@ -551,7 +598,7 @@ Platform-specific environment variables also available:
# Install system library
[tool.cibuildwheel.linux]
- before-all = "yum install -y libffi-dev"
+ before-all = "yum install -y libffi-devel"
# Run multiple commands using an array
before-all = [
@@ -699,6 +746,11 @@ Platform-specific environment variables are also available:
# Pass the `--lib-sdir .` flag to auditwheel on Linux
CIBW_REPAIR_WHEEL_COMMAND_LINUX: "auditwheel repair --lib-sdir . -w {dest_dir} {wheel}"
+
+ # Multi-line example - use && to join on all platforms
+ CIBW_REPAIR_WHEEL_COMMAND: >
+ python scripts/repair_wheel.py -w {dest_dir} {wheel} &&
+ python scripts/check_repaired_wheel.py -w {dest_dir} {wheel}
```
!!! tab examples "pyproject.toml"
@@ -706,16 +758,23 @@ Platform-specific environment variables are also available:
```toml
# Use delvewheel on windows
[tool.cibuildwheel.windows]
- before_build = "pip install delvewheel"
- repair_wheel_command = "delvewheel repair -w {dest_dir} {wheel}"
+ before-build = "pip install delvewheel"
+ repair-wheel-command = "delvewheel repair -w {dest_dir} {wheel}"
# Don't repair macOS wheels
[tool.cibuildwheel.macos]
- repair_wheel_command = ""
+ repair-wheel-command = ""
# Pass the `--lib-sdir .` flag to auditwheel on Linux
[tool.cibuildwheel.linux]
- repair_wheel_command = "auditwheel repair --lib-sdir . -w {dest_dir} {wheel}"
+ repair-wheel-command = "auditwheel repair --lib-sdir . -w {dest_dir} {wheel}"
+
+ # Multi-line example
+ [tool.cibuildwheel]
+ repair-wheel-command = [
+ 'python scripts/repair_wheel.py -w {dest_dir} {wheel}',
+ 'python scripts/check_repaired_wheel.py -w {dest_dir} {wheel}',
+ ]
```
In configuration mode, you can use an inline array, and the items will be joined with `&&`.
@@ -802,7 +861,7 @@ Auditwheel detects the version of the manylinux standard in the Docker image thr
```
Like any other option, these can be placed in `[tool.cibuildwheel.linux]`
- if you perfer; they have no effect on `macos` and `windows`.
+ if you prefer; they have no effect on `macos` and `windows`.
### `CIBW_DEPENDENCY_VERSIONS` {: #dependency-versions}
> Specify how cibuildwheel controls the versions of the tools it uses
@@ -904,6 +963,11 @@ Platform-specific environment variables are also available:
# Trigger an install of the package, but run nothing of note
CIBW_TEST_COMMAND: "echo Wheel installed"
+
+ # Multi-line example - join with && on all platforms
+ CIBW_TEST_COMMAND: >
+ pytest {package}/tests &&
+ python {package}/test.py
```
!!! tab examples "pyproject.toml"
@@ -918,6 +982,12 @@ Platform-specific environment variables are also available:
# Trigger an install of the package, but run nothing of note
test-command = "echo Wheel installed"
+
+ # Multiline example
+ test-command = [
+ "pytest {package}/tests",
+ "python {package}/test.py",
+ ]
```
In configuration files, you can use an array, and the items will be joined with `&&`.
@@ -948,7 +1018,11 @@ Platform-specific environment variables are also available:
CIBW_BEFORE_TEST: rm -rf ./data/cache && mkdir -p ./data/cache
# Install non pip python package
- CIBW_BEFORE_TEST: cd some_dir; ./configure; make; make install
+ CIBW_BEFORE_TEST: >
+ cd some_dir &&
+ ./configure &&
+ make &&
+ make install
# Install python packages that are required to install test dependencies
CIBW_BEFORE_TEST: pip install cmake scikit-build
@@ -1041,7 +1115,7 @@ Platform-specific environment variables are also available:
CIBW_TEST_EXTRAS: "test,qt"
```
- Seperate multiple items with a comma.
+ Separate multiple items with a comma.
!!! tab examples "pyproject.toml"
diff --git a/docs/setup.md b/docs/setup.md
index 6a485315..12cb6b75 100644
--- a/docs/setup.md
+++ b/docs/setup.md
@@ -111,7 +111,7 @@ To build Linux, Mac, and Windows wheels using GitHub Actions, create a `.github/
- uses: actions/checkout@v2
- name: Build wheels
- run: pipx run cibuildwheel==2.0.0a3
+ run: pipx run cibuildwheel==2.1.1
- uses: actions/upload-artifact@v2
with:
@@ -146,7 +146,7 @@ To build Linux, Mac, and Windows wheels using GitHub Actions, create a `.github/
- uses: actions/setup-python@v2
- name: Install cibuildwheel
- run: python -m pip install cibuildwheel==2.0.0a3
+ run: python -m pip install cibuildwheel==2.1.1
- name: Build wheels
run: python -m cibuildwheel --output-dir wheelhouse
diff --git a/examples/appveyor-minimal.yml b/examples/appveyor-minimal.yml
index 03aae825..6d8314b4 100644
--- a/examples/appveyor-minimal.yml
+++ b/examples/appveyor-minimal.yml
@@ -12,7 +12,7 @@ stack: python 3.7
init:
- cmd: set PATH=C:\Python37;C:\Python37\Scripts;%PATH%
-install: python -m pip install cibuildwheel==2.0.0a3
+install: python -m pip install cibuildwheel==2.1.1
build_script: python -m cibuildwheel --output-dir wheelhouse
diff --git a/examples/azure-pipelines-minimal.yml b/examples/azure-pipelines-minimal.yml
index 7ea008d5..e7c56f55 100644
--- a/examples/azure-pipelines-minimal.yml
+++ b/examples/azure-pipelines-minimal.yml
@@ -6,7 +6,7 @@ jobs:
- bash: |
set -o errexit
python3 -m pip install --upgrade pip
- pip3 install cibuildwheel==2.0.0a3
+ pip3 install cibuildwheel==2.1.1
displayName: Install dependencies
- bash: cibuildwheel --output-dir wheelhouse .
displayName: Build wheels
@@ -20,7 +20,7 @@ jobs:
- bash: |
set -o errexit
python3 -m pip install --upgrade pip
- python3 -m pip install cibuildwheel==2.0.0a3
+ python3 -m pip install cibuildwheel==2.1.1
displayName: Install dependencies
- bash: cibuildwheel --output-dir wheelhouse .
displayName: Build wheels
@@ -34,7 +34,7 @@ jobs:
- bash: |
set -o errexit
python -m pip install --upgrade pip
- pip install cibuildwheel==2.0.0a3
+ pip install cibuildwheel==2.1.1
displayName: Install dependencies
- bash: cibuildwheel --output-dir wheelhouse .
displayName: Build wheels
diff --git a/examples/circleci-minimal.yml b/examples/circleci-minimal.yml
index 07c645f8..cbfc2b1b 100644
--- a/examples/circleci-minimal.yml
+++ b/examples/circleci-minimal.yml
@@ -11,7 +11,7 @@ jobs:
- run:
name: Build the Linux wheels.
command: |
- pip3 install --user cibuildwheel==2.0.0a3
+ pip3 install --user cibuildwheel==2.1.1
cibuildwheel --output-dir wheelhouse
- store_artifacts:
path: wheelhouse/
@@ -19,13 +19,13 @@ jobs:
osx-wheels:
working_directory: ~/osx-wheels
macos:
- xcode: 10.0.0
+ xcode: 12.5.1
steps:
- checkout
- run:
name: Build the OS X wheels.
command: |
- pip3 install cibuildwheel==2.0.0a3
+ pip3 install cibuildwheel==2.1.1
cibuildwheel --output-dir wheelhouse
- store_artifacts:
path: wheelhouse/
diff --git a/examples/github-apple-silicon.yml b/examples/github-apple-silicon.yml
index dfb38327..20011cd3 100644
--- a/examples/github-apple-silicon.yml
+++ b/examples/github-apple-silicon.yml
@@ -10,7 +10,7 @@ jobs:
- uses: actions/checkout@v2
- name: Build wheels
- uses: pypa/cibuildwheel@v2.0.0a3
+ uses: pypa/cibuildwheel@v2.1.1
env:
CIBW_ARCHS_MACOS: x86_64 universal2
diff --git a/examples/github-deploy.yml b/examples/github-deploy.yml
index e1e1b691..dd974f08 100644
--- a/examples/github-deploy.yml
+++ b/examples/github-deploy.yml
@@ -27,7 +27,7 @@ jobs:
python-version: '3.8'
- name: Build wheels
- uses: pypa/cibuildwheel@v2.0.0a3
+ uses: pypa/cibuildwheel@v2.1.1
- uses: actions/upload-artifact@v2
with:
diff --git a/examples/github-minimal.yml b/examples/github-minimal.yml
index 7a112402..20d6f1e3 100644
--- a/examples/github-minimal.yml
+++ b/examples/github-minimal.yml
@@ -14,7 +14,7 @@ jobs:
- uses: actions/checkout@v2
- name: Build wheels
- uses: pypa/cibuildwheel@v2.0.0a3
+ uses: pypa/cibuildwheel@v2.1.1
# to supply options, put them in 'env', like:
# env:
# CIBW_SOME_OPTION: value
diff --git a/examples/github-with-qemu.yml b/examples/github-with-qemu.yml
index 58731b97..71b7f3ff 100644
--- a/examples/github-with-qemu.yml
+++ b/examples/github-with-qemu.yml
@@ -25,7 +25,7 @@ jobs:
platforms: all
- name: Build wheels
- uses: pypa/cibuildwheel@v2.0.0a3
+ uses: pypa/cibuildwheel@v2.1.1
env:
# configure cibuildwheel to build native archs ('auto'), and some
# emulated ones
diff --git a/examples/gitlab-minimal.yml b/examples/gitlab-minimal.yml
index 75594aa3..5cc4994a 100644
--- a/examples/gitlab-minimal.yml
+++ b/examples/gitlab-minimal.yml
@@ -12,7 +12,7 @@ linux:
DOCKER_TLS_CERTDIR: ""
script:
- curl -sSL https://get.docker.com/ | sh
- - python -m pip install cibuildwheel==2.0.0a3
+ - python -m pip install cibuildwheel==2.1.1
- cibuildwheel --output-dir wheelhouse
artifacts:
paths:
diff --git a/examples/travis-ci-deploy.yml b/examples/travis-ci-deploy.yml
index 8da7ffd1..d189b0d9 100644
--- a/examples/travis-ci-deploy.yml
+++ b/examples/travis-ci-deploy.yml
@@ -19,7 +19,7 @@ jobs:
- ln -s /c/Python38/python.exe /c/Python38/python3.exe
install:
- - python3 -m pip install cibuildwheel==2.0.0a3
+ - python3 -m pip install cibuildwheel==2.1.1
script:
# build the wheels, put them into './wheelhouse'
diff --git a/examples/travis-ci-minimal.yml b/examples/travis-ci-minimal.yml
index aa6da795..3a8796e1 100644
--- a/examples/travis-ci-minimal.yml
+++ b/examples/travis-ci-minimal.yml
@@ -25,7 +25,7 @@ jobs:
- ln -s /c/Python38/python.exe /c/Python38/python3.exe
install:
- - python3 -m pip install cibuildwheel==2.0.0a3
+ - python3 -m pip install cibuildwheel==2.1.1
script:
# build the wheels, put them into './wheelhouse'
diff --git a/examples/travis-ci-test-and-deploy.yml b/examples/travis-ci-test-and-deploy.yml
index 658721b9..057818b8 100644
--- a/examples/travis-ci-test-and-deploy.yml
+++ b/examples/travis-ci-test-and-deploy.yml
@@ -57,7 +57,7 @@ jobs:
- stage: deploy
name: Build and deploy Linux wheels
services: docker
- install: python3 -m pip install cibuildwheel==2.0.0a3
+ install: python3 -m pip install cibuildwheel==2.1.1
script: python3 -m cibuildwheel --output-dir wheelhouse
after_success: |
python3 -m pip install twine
@@ -67,7 +67,7 @@ jobs:
name: Build and deploy Windows wheels
os: windows
language: shell
- install: python3 -m pip install cibuildwheel==2.0.0a3
+ install: python3 -m pip install cibuildwheel==2.1.1
script: python3 -m cibuildwheel --output-dir wheelhouse
after_success: |
python3 -m pip install twine
diff --git a/noxfile.py b/noxfile.py
index 1ed4959a..211cceb7 100644
--- a/noxfile.py
+++ b/noxfile.py
@@ -12,7 +12,7 @@ DIR = Path(__file__).parent.resolve()
@nox.session
-def tests(session):
+def tests(session: nox.Session) -> None:
"""
Run the unit and regular tests.
"""
@@ -26,16 +26,16 @@ def tests(session):
@nox.session
-def lint(session):
+def lint(session: nox.Session) -> None:
"""
Run the linter.
"""
session.install("pre-commit")
- session.run("pre-commit", "run", "--all-files")
+ session.run("pre-commit", "run", "--all-files", *session.posargs)
@nox.session(python=PYTHON_ALL_VERSIONS)
-def update_constraints(session):
+def update_constraints(session: nox.Session) -> None:
"""
Update the dependencies inplace.
"""
@@ -44,7 +44,7 @@ def update_constraints(session):
@nox.session
-def update_pins(session):
+def update_pins(session: nox.Session) -> None:
"""
Update the python and docker pins version inplace.
"""
@@ -54,16 +54,22 @@ def update_pins(session):
@nox.session
-def update_proj(session):
+def update_proj(session: nox.Session) -> None:
"""
Update the README inplace.
"""
session.install("-e", ".[bin]")
- session.run("python", "bin/projects.py", "docs/data/projects.yml", "--readme=README.md")
+ session.run(
+ "python",
+ "bin/projects.py",
+ "docs/data/projects.yml",
+ "--readme=README.md",
+ *session.posargs,
+ )
@nox.session
-def docs(session):
+def docs(session: nox.Session) -> None:
"""
Build the docs.
"""
@@ -73,13 +79,13 @@ def docs(session):
if "serve" in session.posargs:
session.run("mkdocs", "serve")
else:
- print("Unrecognized args, use 'serve'")
+ session.error("Unrecognized args, use 'serve'")
else:
session.run("mkdocs", "build")
@nox.session
-def build(session):
+def build(session: nox.Session) -> None:
"""
Build an SDist and wheel.
"""
diff --git a/setup.cfg b/setup.cfg
index 4d7ffce1..291e4fcc 100644
--- a/setup.cfg
+++ b/setup.cfg
@@ -1,6 +1,6 @@
[metadata]
name = cibuildwheel
-version = 2.0.0a3
+version = 2.1.1
description = Build Python wheels on CI with minimal configuration.
long_description = file: README.md
long_description_content_type = text/markdown
diff --git a/setup.py b/setup.py
index b876c789..bcd7324b 100644
--- a/setup.py
+++ b/setup.py
@@ -20,7 +20,7 @@ extras = {
"pyyaml",
"requests",
"rich>=9.6",
- "packaging>=20.8",
+ "packaging>=21.0",
],
"mypy": [
"mypy>=0.901",
diff --git a/test/conftest.py b/test/conftest.py
index 410c0707..6e3293b2 100644
--- a/test/conftest.py
+++ b/test/conftest.py
@@ -1,7 +1,9 @@
+from typing import Dict
+
import pytest
-def pytest_addoption(parser):
+def pytest_addoption(parser) -> None:
parser.addoption(
"--run-emulation", action="store_true", default=False, help="run emulation tests"
)
@@ -11,7 +13,7 @@ def pytest_configure(config):
config.addinivalue_line("markers", "emulation: mark test requiring qemu binfmt_misc to run")
-def pytest_collection_modifyitems(config, items):
+def pytest_collection_modifyitems(config, items) -> None:
if config.getoption("--run-emulation"):
# --run-emulation given in cli: do not skip emulation tests
return
@@ -19,3 +21,10 @@ def pytest_collection_modifyitems(config, items):
for item in items:
if "emulation" in item.keywords:
item.add_marker(skip_emulation)
+
+
+@pytest.fixture(
+ params=[{"CIBW_BUILD_FRONTEND": "pip"}, {"CIBW_BUILD_FRONTEND": "build"}], ids=["pip", "build"]
+)
+def build_frontend_env(request) -> Dict[str, str]:
+ return request.param # type: ignore
diff --git a/test/test_0_basic.py b/test/test_0_basic.py
index a8453226..8f2cd4bf 100644
--- a/test/test_0_basic.py
+++ b/test/test_0_basic.py
@@ -18,12 +18,12 @@ basic_project = test_projects.new_c_project(
)
-def test(tmp_path):
+def test(tmp_path, build_frontend_env):
project_dir = tmp_path / "project"
basic_project.generate(project_dir)
# build the wheels
- actual_wheels = utils.cibuildwheel_run(project_dir)
+ actual_wheels = utils.cibuildwheel_run(project_dir, add_env=build_frontend_env)
# check that the expected wheels are produced
expected_wheels = utils.expected_wheels("spam", "0.1.0")
diff --git a/test/test_before_build.py b/test/test_before_build.py
index f84bd800..00906acc 100644
--- a/test/test_before_build.py
+++ b/test/test_before_build.py
@@ -25,8 +25,13 @@ project_with_before_build_asserts = test_projects.new_c_project(
stored_executable = f.read()
print('stored_executable', stored_executable)
print('sys.executable', sys.executable)
+
# windows/mac are case insensitive
- assert os.path.realpath(stored_executable).lower() == os.path.realpath(sys.executable).lower()
+ stored_path = os.path.realpath(stored_executable).lower()
+ current_path = os.path.realpath(sys.executable).lower()
+
+ # TODO: This is not valid in an virtual environment
+ assert stored_path == current_path, '{0} != {1}'.format(stored_path, current_path)
"""
)
)
diff --git a/test/test_dependency_versions.py b/test/test_dependency_versions.py
index dc1f0b50..18589f8f 100644
--- a/test/test_dependency_versions.py
+++ b/test/test_dependency_versions.py
@@ -48,7 +48,7 @@ def get_versions_from_constraint_file(constraint_file):
@pytest.mark.parametrize("python_version", ["3.6", "3.8", "3.9"])
-def test_pinned_versions(tmp_path, python_version):
+def test_pinned_versions(tmp_path, python_version, build_frontend_env):
if utils.platform == "linux":
pytest.skip("linux doesn't pin individual tool versions, it pins manylinux images instead")
@@ -85,6 +85,7 @@ def test_pinned_versions(tmp_path, python_version):
add_env={
"CIBW_BUILD": build_pattern,
"CIBW_ENVIRONMENT": cibw_environment_option,
+ **build_frontend_env,
},
)
@@ -107,7 +108,7 @@ def test_pinned_versions(tmp_path, python_version):
assert set(actual_wheels) == set(expected_wheels)
-def test_dependency_constraints_file(tmp_path):
+def test_dependency_constraints_file(tmp_path, build_frontend_env):
if utils.platform == "linux":
pytest.skip("linux doesn't pin individual tool versions, it pins manylinux images instead")
@@ -118,10 +119,10 @@ def test_dependency_constraints_file(tmp_path):
"pip": "20.0.2",
"setuptools": "53.0.0",
"wheel": "0.34.2",
- "virtualenv": "20.0.10",
+ "virtualenv": "20.0.35",
}
- constraints_file = tmp_path / "constraints.txt"
+ constraints_file = tmp_path / "constraints file.txt"
constraints_file.write_text(
textwrap.dedent(
"""
@@ -129,6 +130,7 @@ def test_dependency_constraints_file(tmp_path):
setuptools=={setuptools}
wheel=={wheel}
virtualenv=={virtualenv}
+ importlib-metadata<3,>=0.12; python_version < "3.8"
""".format(
**tool_versions
)
@@ -149,6 +151,7 @@ def test_dependency_constraints_file(tmp_path):
add_env={
"CIBW_ENVIRONMENT": cibw_environment_option,
"CIBW_DEPENDENCY_VERSIONS": str(constraints_file),
+ **build_frontend_env,
},
)
diff --git a/test/test_pep518.py b/test/test_pep518.py
index 921024f5..12883428 100644
--- a/test/test_pep518.py
+++ b/test/test_pep518.py
@@ -1,4 +1,3 @@
-import os
import textwrap
from . import test_projects, utils
@@ -33,13 +32,13 @@ build-backend = "setuptools.build_meta"
"""
-def test_pep518(tmp_path):
+def test_pep518(tmp_path, build_frontend_env):
project_dir = tmp_path / "project"
basic_project.generate(project_dir)
# build the wheels
- actual_wheels = utils.cibuildwheel_run(project_dir)
+ actual_wheels = utils.cibuildwheel_run(project_dir, add_env=build_frontend_env)
# check that the expected wheels are produced
expected_wheels = utils.expected_wheels("spam", "0.1.0")
@@ -50,4 +49,12 @@ def test_pep518(tmp_path):
assert not (project_dir / "42").exists()
assert not (project_dir / "4.1.2").exists()
- assert len(os.listdir(project_dir)) == len(basic_project.files)
+ # pypa/build creates a "build" folder & a "*.egg-info" folder for the wheel being built,
+ # this should be harmless so remove them
+ contents = [
+ item
+ for item in project_dir.iterdir()
+ if item.name != "build" and not item.name.endswith(".egg-info")
+ ]
+
+ assert len(contents) == len(basic_project.files)
diff --git a/test/test_troubleshooting.py b/test/test_troubleshooting.py
index e1d2cf8d..6a58ca1f 100644
--- a/test/test_troubleshooting.py
+++ b/test/test_troubleshooting.py
@@ -16,7 +16,7 @@ raise Exception('this build will fail')
"""
-def test_failed_project_with_so_files(tmp_path, capfd):
+def test_failed_project_with_so_files(tmp_path, capfd, build_frontend_env):
if utils.platform != "linux":
pytest.skip("this test is only relevant to the linux build")
@@ -24,7 +24,7 @@ def test_failed_project_with_so_files(tmp_path, capfd):
so_file_project.generate(project_dir)
with pytest.raises(subprocess.CalledProcessError):
- utils.cibuildwheel_run(project_dir)
+ utils.cibuildwheel_run(project_dir, add_env=build_frontend_env)
captured = capfd.readouterr()
print("out", captured.out)
diff --git a/unit_test/build_selector_test.py b/unit_test/build_selector_test.py
index 76131c81..c99b28f1 100644
--- a/unit_test/build_selector_test.py
+++ b/unit_test/build_selector_test.py
@@ -1,3 +1,4 @@
+import pytest
from packaging.specifiers import SpecifierSet
from cibuildwheel.util import BuildSelector
@@ -8,7 +9,7 @@ def test_build():
assert build_selector("cp36-manylinux_x86_64")
assert build_selector("cp37-manylinux_x86_64")
- assert not build_selector("cp310-manylinux_x86_64")
+ assert build_selector("cp310-manylinux_x86_64")
assert build_selector("pp36-manylinux_x86_64")
assert build_selector("pp37-manylinux_x86_64")
assert build_selector("cp36-manylinux_i686")
@@ -26,11 +27,12 @@ def test_build():
assert not build_selector("pp37-win32")
assert build_selector("cp36-win_amd64")
assert build_selector("cp37-win_amd64")
- assert not build_selector("cp310-win_amd64")
+ assert build_selector("cp310-win_amd64")
assert not build_selector("pp36-win_amd64")
assert not build_selector("pp37-win_amd64")
+@pytest.mark.skip("this test only makes sense when we have a prerelease python to test with")
def test_build_filter_pre():
build_selector = BuildSelector(
build_config="cp3*-* *-manylinux*",
diff --git a/unit_test/environment_test.py b/unit_test/environment_test.py
index c1ffef09..c5162aea 100644
--- a/unit_test/environment_test.py
+++ b/unit_test/environment_test.py
@@ -106,10 +106,12 @@ def test_substitution_with_backslash():
def test_awkwardly_quoted_variable():
environment_recipe = parse_environment(
- 'VAR2=something"like this""$VAR1"$VAR1$(echo "theres more")"$(echo "and more!")"'
+ 'VAR2=something"like this""$VAR1"$VAR1$(echo "there is more")"$(echo "and more!")"'
)
# pass the existing process env so PATH is available
environment_dict = environment_recipe.as_dictionary({"VAR1": "but wait"})
- assert environment_dict.get("VAR2") == "somethinglike thisbut waitbut waittheres moreand more!"
+ assert (
+ environment_dict.get("VAR2") == "somethinglike thisbut waitbut waitthere is moreand more!"
+ )
diff --git a/cibuildwheel/linux.py b/cibuildwheel/linux.py
index faeff20b..f22304c0 100644
--- a/cibuildwheel/linux.py
+++ b/cibuildwheel/linux.py
@@ -7,7 +7,7 @@ from typing import List, NamedTuple, Set
from .architecture import Architecture
from .docker_container import DockerContainer
from .logger import log
-from .typing import PathOrStr
+from .typing import PathOrStr, assert_never
from .util import (
BuildOptions,
BuildSelector,
@@ -145,7 +145,7 @@ def build(options: BuildOptions) -> None:
env, executor=docker.environment_executor
)
- # check config python and pip are still on PATH
+ # check config python is still on PATH
which_python = docker.call(
["which", "python"], env=env, capture_output=True
).strip()
@@ -180,18 +180,38 @@ def build(options: BuildOptions) -> None:
docker.call(["rm", "-rf", built_wheel_dir])
docker.call(["mkdir", "-p", built_wheel_dir])
- docker.call(
- [
- "pip",
- "wheel",
- container_package_dir,
- "--wheel-dir",
- built_wheel_dir,
- "--no-deps",
- *get_build_verbosity_extra_flags(options.build_verbosity),
- ],
- env=env,
- )
+ verbosity_flags = get_build_verbosity_extra_flags(options.build_verbosity)
+
+ if options.build_frontend == "pip":
+ docker.call(
+ [
+ "python",
+ "-m",
+ "pip",
+ "wheel",
+ container_package_dir,
+ f"--wheel-dir={built_wheel_dir}",
+ "--no-deps",
+ *verbosity_flags,
+ ],
+ env=env,
+ )
+ elif options.build_frontend == "build":
+ config_setting = " ".join(verbosity_flags)
+ docker.call(
+ [
+ "python",
+ "-m",
+ "build",
+ container_package_dir,
+ "--wheel",
+ f"--outdir={built_wheel_dir}",
+ f"--config-setting={config_setting}",
+ ],
+ env=env,
+ )
+ else:
+ assert_never(options.build_frontend)
built_wheel = docker.glob(built_wheel_dir, "*.whl")[0]
@@ -291,8 +311,11 @@ def build(options: BuildOptions) -> None:
def troubleshoot(package_dir: Path, error: Exception) -> None:
- if isinstance(error, subprocess.CalledProcessError) and error.cmd[0:2] == ["pip", "wheel"]:
- # the 'pip wheel' step failed.
+ if isinstance(error, subprocess.CalledProcessError) and (
+ error.cmd[0:4] == ["python", "-m", "pip", "wheel"]
+ or error.cmd[0:3] == ["python", "-m", "build"]
+ ):
+ # the wheel build step failed
print("Checking for common errors...")
so_files = list(package_dir.glob("**/*.so"))
diff --git a/cibuildwheel/macos.py b/cibuildwheel/macos.py
index cbaeae61..d8f6dbc5 100644
--- a/cibuildwheel/macos.py
+++ b/cibuildwheel/macos.py
@@ -12,13 +12,15 @@ from typing import Any, Dict, List, NamedTuple, Optional, Sequence, Set, Tuple,
from .architecture import Architecture
from .environment import ParsedEnvironment
from .logger import log
-from .typing import Literal, PathOrStr
+from .typing import Literal, PathOrStr, assert_never
from .util import (
+ BuildFrontend,
BuildOptions,
BuildSelector,
NonPlatformWheelError,
download,
get_build_verbosity_extra_flags,
+ get_pip_version,
install_certifi_script,
prepare_command,
read_python_configs,
@@ -178,7 +180,9 @@ def setup_python(
python_configuration: PythonConfiguration,
dependency_constraint_flags: Sequence[PathOrStr],
environment: ParsedEnvironment,
+ build_frontend: BuildFrontend,
) -> Dict[str, str]:
+
implementation_id = python_configuration.identifier.split("-")[0]
log.step(f"Installing Python {implementation_id}...")
@@ -308,18 +312,33 @@ def setup_python(
env.setdefault("SDKROOT", arm64_compatible_sdks[0])
log.step("Installing build tools...")
- call(
- [
- "pip",
- "install",
- "--upgrade",
- "setuptools",
- "wheel",
- "delocate",
- *dependency_constraint_flags,
- ],
- env=env,
- )
+ if build_frontend == "pip":
+ call(
+ [
+ "pip",
+ "install",
+ "--upgrade",
+ "setuptools",
+ "wheel",
+ "delocate",
+ *dependency_constraint_flags,
+ ],
+ env=env,
+ )
+ elif build_frontend == "build":
+ call(
+ [
+ "pip",
+ "install",
+ "--upgrade",
+ "delocate",
+ "build[virtualenv]",
+ *dependency_constraint_flags,
+ ],
+ env=env,
+ )
+ else:
+ assert_never(build_frontend)
return env
@@ -356,7 +375,12 @@ def build(options: BuildOptions) -> None:
options.dependency_constraints.get_for_python_version(config.version),
]
- env = setup_python(config, dependency_constraint_flags, options.environment)
+ env = setup_python(
+ config,
+ dependency_constraint_flags,
+ options.environment,
+ options.build_frontend,
+ )
if options.before_build:
log.step("Running before_build...")
@@ -370,20 +394,45 @@ def build(options: BuildOptions) -> None:
shutil.rmtree(built_wheel_dir)
built_wheel_dir.mkdir(parents=True)
- # Path.resolve() is needed. Without it pip wheel may try to fetch package from pypi.org
- # see https://github.com/pypa/cibuildwheel/pull/369
- call(
- [
- "pip",
- "wheel",
- options.package_dir.resolve(),
- "--wheel-dir",
- built_wheel_dir,
- "--no-deps",
- *get_build_verbosity_extra_flags(options.build_verbosity),
- ],
- env=env,
- )
+ verbosity_flags = get_build_verbosity_extra_flags(options.build_verbosity)
+
+ if options.build_frontend == "pip":
+ # Path.resolve() is needed. Without it pip wheel may try to fetch package from pypi.org
+ # see https://github.com/pypa/cibuildwheel/pull/369
+ call(
+ [
+ "python",
+ "-m",
+ "pip",
+ "wheel",
+ options.package_dir.resolve(),
+ f"--wheel-dir={built_wheel_dir}",
+ "--no-deps",
+ *verbosity_flags,
+ ],
+ env=env,
+ )
+ elif options.build_frontend == "build":
+ config_setting = " ".join(verbosity_flags)
+ build_env = env.copy()
+ if options.dependency_constraints:
+ constr = options.dependency_constraints.get_for_python_version(config.version)
+ build_env["PIP_CONSTRAINT"] = constr.as_uri()
+ build_env["VIRTUALENV_PIP"] = get_pip_version(env)
+ call(
+ [
+ "python",
+ "-m",
+ "build",
+ options.package_dir,
+ "--wheel",
+ f"--outdir={built_wheel_dir}",
+ f"--config-setting={config_setting}",
+ ],
+ env=build_env,
+ )
+ else:
+ assert_never(options.build_frontend)
built_wheel = next(built_wheel_dir.glob("*.whl"))